@@ -13,7 +13,7 @@ use JSON;
 use Getopt::Std;
 use IO::String;
 
-our $VERSION = '1.9.3';
+our $VERSION = '1.9.7';
 
 has structFile            => ( isa => 'Str', is => 'ro', required => 1 );
 has confTreeFile          => ( isa => 'Str', is => 'ro', required => 1 );
@@ -37,6 +37,7 @@ my $mainTree;
 my @sessionTypes;
 my @simpleHashKeys;
 my @doubleHashKeys;
+my $defaultValues;
 
 my $attributes = Lemonldap::NG::Manager::Build::Attributes::attributes();
 my $jsonEnc    = JSON->new()->allow_nonref;
@@ -121,6 +122,9 @@ sub run {
     $ignoreKeys   = $ra->as_string;
     $reIgnoreKeys = $ra->re;
 
+    # Reinitialize $defaultValues
+    $defaultValues = {};
+
     # 2. struct.json
     printf STDERR $format, $self->structFile;
     $mainTree = Lemonldap::NG::Manager::Build::Tree::tree();
@@ -149,9 +153,9 @@ sub run {
     my $sessionTypes = join( "', '", @sessionTypes );
 
     open F, ">", $self->managerConstantsFile or die($!);
-    my $exportedVars =
-        '$'
-      . join( 'Keys $', 'simpleHash', 'specialNode', 'doubleHash', sort keys %cnodesRe )
+    my $exportedVars = '$'
+      . join( 'Keys $',
+        'simpleHash', 'specialNode', 'doubleHash', sort keys %cnodesRe )
       . 'Keys $specialNodeHash @sessionTypes';
     print F <<EOF;
 # This file is generated by $module. Don't modify it by hand
@@ -172,7 +176,7 @@ our \$specialNodeHash = {
     samlIDPMetaDataNodes => [qw(samlIDPMetaDataXML samlIDPMetaDataExportedAttributes samlIDPMetaDataOptions)],
     samlSPMetaDataNodes  => [qw(samlSPMetaDataXML samlSPMetaDataExportedAttributes samlSPMetaDataOptions)],
     oidcOPMetaDataNodes  => [qw(oidcOPMetaDataJSON oidcOPMetaDataJWKS oidcOPMetaDataOptions oidcOPMetaDataExportedVars)],
-    oidcRPMetaDataNodes  => [qw(oidcRPMetaDataOptions oidcRPMetaDataExportedVars)],
+    oidcRPMetaDataNodes  => [qw(oidcRPMetaDataOptions oidcRPMetaDataExportedVars oidcRPMetaDataOptionsExtraClaims)],
 };
 
 our \@sessionTypes = ( '$sessionTypes' );
@@ -202,13 +206,7 @@ EOF
     print STDERR "done\n";
 
     printf STDERR $format, $self->defaultValuesFile;
-    my $defaultValues = {
-        map {
-            defined $attributes->{$_}->{default}
-              ? ( $_ => $attributes->{$_}->{default} )
-              : ()
-        } keys(%$attributes)
-    };
+    $defaultValues->{locationRules} = $attributes->{locationRules}->{default};
     my $defaultAttr = mydump( $defaultValues, 'defaultValues' );
     $defaultAttr = "# This file is generated by $module. Don't modify it by hand
 package Lemonldap::NG::Common::Conf::DefaultValues;
@@ -248,7 +246,7 @@ $defaultAttr}
         samlSPMetaDataExportedAttributes samlSPMetaDataOptions
         oidcOPMetaDataJSON oidcOPMetaDataJWKS oidcOPMetaDataOptions
         oidcOPMetaDataExportedVars oidcRPMetaDataOptions
-        oidcRPMetaDataExportedVars)
+        oidcRPMetaDataExportedVars oidcRPMetaDataOptionsExtraClaims)
       )
     {
         $ra->add($_);
@@ -453,23 +451,26 @@ sub scanTree {
             foreach my $w (qw(default help select get template)) {
                 $jleaf->{$w} = $attr->{$w} if ( defined $attr->{$w} );
             }
-            if ( $jleaf->{default} and ref( $jleaf->{default} ) ) {
-                $jleaf->{default} = [];
-                my $type = $attr->{type};
-                $type =~ s/Container//;
-                foreach my $k ( sort keys( %{ $attr->{default} } ) ) {
-                    push @{ $jleaf->{default} },
-                      {
-                        id    => "$prefix$leaf/$k",
-                        title => $k,
-                        type  => $type,
-                        data  => $attr->{default}->{$k},
-                        (
-                            $type eq 'rule'
-                            ? ( re => $k )
-                            : ()
-                        ),
-                      };
+            if ( defined $jleaf->{default} ) {
+                $defaultValues->{$leaf} = $jleaf->{default};
+                if ( ref( $jleaf->{default} ) ) {
+                    $jleaf->{default} = [];
+                    my $type = $attr->{type};
+                    $type =~ s/Container//;
+                    foreach my $k ( sort keys( %{ $attr->{default} } ) ) {
+                        push @{ $jleaf->{default} },
+                          {
+                            id    => "$prefix$leaf/$k",
+                            title => $k,
+                            type  => $type,
+                            data  => $attr->{default}->{$k},
+                            (
+                                $type eq 'rule'
+                                ? ( re => $k )
+                                : ()
+                            ),
+                          };
+                    }
                 }
             }
             if ($prefix) {
@@ -522,7 +523,7 @@ system.
 Lemonldap::NG::Manager::Build is used only to build javascript files and
 Lemonldap::NG constants Perl files. It has to be launched after each change.
 
-=head2 DEVELOPPER CORNER
+=head2 DEVELOPER CORNER
 
 To add a new parameter, you have to:
 
@@ -680,7 +681,7 @@ L<Lemonldap::NG::Manager>, L<http://lemonldap-ng.org/>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://jira.ow2.org>
+L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 
 =head1 DOWNLOAD
 
